==> AGXUnreal-1.17.0_UE-5.5_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/DriveTrain/Shaft.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/DriveTrain/DriveTrainForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics1D/Physics1DForward.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Physics1D/Bodies/RotationalBody.h>
#include <openplx/Physics1D/Charges/MateConnector.h>
/* Generated code for model Shaft */
namespace openplx::DriveTrain {
    class Shaft : public openplx::Physics1D::Bodies::RotationalBody {
        protected:
            std::shared_ptr<openplx::Physics1D::Charges::MateConnector> m_input;
            std::shared_ptr<openplx::Physics1D::Charges::MateConnector> m_output;

        public:
            Shaft();
            std::shared_ptr<openplx::Physics1D::Charges::MateConnector> input() const;
            std::shared_ptr<openplx::Physics1D::Charges::MateConnector> output() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.1.1_UE-5.7_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/DriveTrain/Shaft.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/DriveTrain/DriveTrainBundleExport.h>
#include <openplx/DriveTrain/DriveTrainForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics1D/Physics1DForward.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Physics1D/Bodies/RotationalBody.h>
#include <openplx/Physics1D/Interactions/MateConnector.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model Shaft */
namespace openplx::DriveTrain {
    class OPENPLX_DriveTrain_BUNDLE_EXPORT Shaft : public openplx::Physics1D::Bodies::RotationalBody {
        protected:
            std::shared_ptr<openplx::Physics1D::Interactions::MateConnector> m_input;
            std::shared_ptr<openplx::Physics1D::Interactions::MateConnector> m_output;

        public:
            Shaft();
            virtual ~Shaft();
            std::shared_ptr<openplx::Physics1D::Interactions::MateConnector> input() const;
            std::shared_ptr<openplx::Physics1D::Interactions::MateConnector> output() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
